@@ -53,8 +53,15 @@ class DataFrame:
     def __getattr__(self, key):        
         return self.d[key]
     def __setattr__(self, name, value):
+        if type(value) == dict:
+            raise Exception("Cannot insert a dictionary")
         if type(value) == list:
-            value = np.array(value)        
+            try:
+                value = np.array(value)
+            except:
+                value = np.array(value,dtype=object)
+        if type(value) != np.ndarray:
+            value = np.array([value])
         self.d[name] = value
         self.names()
         super(DataFrame, self).__setattr__('ncol', len(self.d.keys()))
@@ -64,6 +71,8 @@ class DataFrame:
     def __getitem__(self,args):
         if type(args) == tuple:
             rows,key=args
+            if type(rows) == int:
+                rows = [rows]
             if type(key) == slice:
                 
                 if key.start is None:
@@ -126,6 +135,8 @@ class DataFrame:
     def __setitem__(self,args,values):
         if type(args) == tuple:
             rows,key = args
+            if type(rows) == int:
+                rows = [rows]
             if type(key) == str or type(key) == int:
                 if type(key) == int:
                     key = list(self.d.keys())[key]
